==> checker-3.36.0.jar: annotated-jdk/src/java.base/share/classes/sun/security/x509/X509CertInfo.java <==
/*
 * Copyright (c) 1997, 2014, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package sun.security.x509;

import org.checkerframework.checker.nullness.qual.EnsuresNonNullIf;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.dataflow.qual.SideEffectFree;
import java.io.IOException;
import java.io.OutputStream;
import java.security.cert.*;
import java.util.*;
import sun.security.util.*;
import sun.security.util.HexDumpEncoder;

public class X509CertInfo implements CertAttrSet<String> {

    public static final String IDENT;

    public static final String NAME;

    public static final String DN_NAME;

    public static final String VERSION;

    public static final String SERIAL_NUMBER;

    public static final String ALGORITHM_ID;

    public static final String ISSUER;

    public static final String SUBJECT;

    public static final String VALIDITY;

    public static final String KEY;

    public static final String ISSUER_ID;

    public static final String SUBJECT_ID;

    public static final String EXTENSIONS;

    protected CertificateVersion version;

    protected CertificateSerialNumber serialNum;

    protected CertificateAlgorithmId algId;

    protected X500Name issuer;

    protected X500Name subject;

    protected CertificateValidity interval;

    protected CertificateX509Key pubKey;

    protected UniqueIdentity issuerUniqueId;

    protected UniqueIdentity subjectUniqueId;

    protected CertificateExtensions extensions;

    public X509CertInfo() {
    }

    public X509CertInfo(byte[] cert) throws CertificateParsingException {
    }

    public X509CertInfo(DerValue derVal) throws CertificateParsingException {
    }

    public void encode(OutputStream out) throws CertificateException, IOException;

    public Enumeration<String> getElements();

    public String getName();

    public byte[] getEncodedInfo() throws CertificateEncodingException;

    @Pure
    @EnsuresNonNullIf(expression = "#1", result = true)
    public boolean equals(@Nullable Object other);

    public boolean equals(X509CertInfo other);

    public int hashCode();

    public String toString();

    public void set(String name, Object val) throws CertificateException, IOException;

    public void delete(String name) throws CertificateException, IOException;

    public Object get(String name) throws CertificateException, IOException;
}

==> checker-3.53.0.jar: annotated-jdk/src/java.base/share/classes/sun/security/x509/X509CertInfo.java <==
/*
 * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package sun.security.x509;

import org.checkerframework.checker.nullness.qual.EnsuresNonNullIf;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.dataflow.qual.SideEffectFree;
import java.io.IOException;
import java.security.cert.*;
import java.util.*;
import sun.security.util.*;
import sun.security.util.HexDumpEncoder;

public class X509CertInfo {

    public static final String NAME;

    public static final String DN_NAME;

    public static final String VERSION;

    public static final String SERIAL_NUMBER;

    public static final String ALGORITHM_ID;

    public static final String ISSUER;

    public static final String SUBJECT;

    public static final String VALIDITY;

    public static final String KEY;

    public static final String ISSUER_ID;

    public static final String SUBJECT_ID;

    public static final String EXTENSIONS;

    protected CertificateVersion version;

    protected CertificateSerialNumber serialNum;

    protected CertificateAlgorithmId algId;

    protected X500Name issuer;

    protected X500Name subject;

    protected CertificateValidity interval;

    protected CertificateX509Key pubKey;

    protected UniqueIdentity issuerUniqueId;

    protected UniqueIdentity subjectUniqueId;

    protected CertificateExtensions extensions;

    public X509CertInfo() {
    }

    public X509CertInfo(byte[] cert) throws CertificateParsingException {
    }

    public X509CertInfo(DerValue derVal) throws CertificateParsingException {
    }

    public void encode(DerOutputStream out) throws CertificateException;

    public byte[] getEncodedInfo() throws CertificateEncodingException;

    @Pure
    @EnsuresNonNullIf(expression = "#1", result = true)
    public boolean equals(@Nullable Object other);

    public boolean equals(X509CertInfo other);

    public int hashCode();

    public String toString();

    public CertificateExtensions getExtensions();

    public UniqueIdentity getIssuerUniqueId();

    public UniqueIdentity getSubjectUniqueId();

    public X500Name getIssuer();

    public X500Name getSubject();

    public void setVersion(CertificateVersion val);

    public CertificateVersion getVersion();

    public void setSerialNumber(CertificateSerialNumber val);

    public CertificateSerialNumber getSerialNumber();

    public void setAlgorithmId(CertificateAlgorithmId val);

    public CertificateAlgorithmId getAlgorithmId();

    public void setIssuer(X500Name val);

    public void setValidity(CertificateValidity val);

    public CertificateValidity getValidity();

    public void setSubject(X500Name val) throws CertificateException;

    public void setKey(CertificateX509Key val);

    public CertificateX509Key getKey();

    public void setIssuerUniqueId(UniqueIdentity val) throws CertificateException;

    public void setSubjectUniqueId(UniqueIdentity val) throws CertificateException;

    public void setExtensions(CertificateExtensions val) throws CertificateException;
}
